@@ -1,6 +1,7 @@
 import json
 from enum import Enum
 import requests
+from typing import Optional
 
 
 class SolanaNetwork(Enum):
@@ -111,7 +112,7 @@ class TheBlockchainAPIResource:
     def derive_public_key(
         self,
         secret_recovery_phrase: str,
-        derivation_path: str = "m/44/501/0/0",
+        derivation_path: Optional[str] = None,
         passphrase: str = str()
     ) -> str:
         """
@@ -124,9 +125,10 @@ class TheBlockchainAPIResource:
         """
         payload = {
             "secret_recovery_phrase": secret_recovery_phrase,
-            "derivation_path": derivation_path,
             "passphrase": passphrase
         }
+        if derivation_path is not None:
+            payload["derivation_path"] = derivation_path
 
         response = self._request(
             payload=payload,
@@ -194,7 +196,7 @@ class TheBlockchainAPIResource:
         self,
         token_address: str,
         secret_recovery_phrase: str,
-        derivation_path: str = "m/44/501/0/0",
+        derivation_path: Optional[str] = None,
         passphrase: str = str(),
         network: SolanaNetwork = SolanaNetwork.DEVNET
     ) -> str:
@@ -210,10 +212,11 @@ class TheBlockchainAPIResource:
         payload = {
             "token_address": token_address,
             "secret_recovery_phrase": secret_recovery_phrase,
-            "derivation_path": derivation_path,
             "passphrase": passphrase,
             "network": network.value
         }
+        if derivation_path is not None:
+            payload["derivation_path"] = derivation_path
 
         response = self._request(
             payload=payload,
@@ -229,7 +232,7 @@ class TheBlockchainAPIResource:
         token_address: str,
         recipient_address: str,
         secret_recovery_phrase: str,
-        derivation_path: str = "m/44/501/0/0",
+        derivation_path: Optional[str] = None,
         passphrase: str = str(),
         network: SolanaNetwork = SolanaNetwork.DEVNET,
         amount: str = "1"
@@ -249,11 +252,12 @@ class TheBlockchainAPIResource:
             "token_address": token_address,
             "recipient_address": recipient_address,
             "secret_recovery_phrase": secret_recovery_phrase,
-            "derivation_path": derivation_path,
             "passphrase": passphrase,
             "network": network.value,
             "amount": amount
         }
+        if derivation_path is not None:
+            payload['derivation_path'] = derivation_path
 
         response = self._request(
             payload=payload,
@@ -267,7 +271,7 @@ class TheBlockchainAPIResource:
     def create_nft(
         self,
         secret_recovery_phrase: str,
-        derivation_path: str = "m/44/501/0/0",
+        derivation_path: Optional[str] = None,
         passphrase: str = str(),
         network: SolanaNetwork = SolanaNetwork.DEVNET,
         nft_name: str = str(),
@@ -293,7 +297,6 @@ class TheBlockchainAPIResource:
             nft_metadata = dict()
         payload = {
             "secret_recovery_phrase": secret_recovery_phrase,
-            "derivation_path": derivation_path,
             "passphrase": passphrase,
             "network": network.value,
             "nft_name": nft_name,
@@ -302,6 +305,8 @@ class TheBlockchainAPIResource:
             "nft_url": nft_url,
             "nft_metadata": nft_metadata
         }
+        if derivation_path is not None:
+            payload['derivation_path'] = derivation_path
 
         response = self._request(
             payload=payload,
@@ -358,7 +363,7 @@ class TheBlockchainAPIResource:
         recipient_address: str
     ) -> str:
         """
-        Get an airdrop of 0.015 SOL on the devnet
+        Get an airdrop of 0.02 SOL on the devnet
         :param recipient_address:
         :return: Transaction signature
         """
